@@ -341,11 +341,11 @@ class Actor(Model):
         client = sys.modules[module_name].AgentClient
         return client(self, bot, headers=self.agent.auth.get("headers"), cookies=self.agent.auth.get("cookies"))
 
-    def in_client(self):
+    def in_client(self, bot):
         module_name = f"xync_client.{self.ex.name}.InAgent"
         __import__(module_name)
         client = sys.modules[module_name].InAgentClient
-        return client(self)
+        return client(self, bot)
 
     def asset_client(self):
         module_name = f"xync_client.{self.ex.name}.asset"
@@ -425,6 +425,7 @@ class Pm(Model):
     extra: str | None = CharField(63, null=True)
     ok: bool = BooleanField(default=True)
     bank: bool | None = BooleanField(null=True)
+    qr: bool = BooleanField(default=False)
 
     typ: PmType | None = IntEnumField(PmType, null=True)
 
@@ -544,7 +545,7 @@ class Race(Model):
 class PmRep(Model):
     ex: ForeignKeyRelation[Ex] = ForeignKeyField("models.Ex", "pm_reps")
     ex_id: int
-    src: str | None = CharField(63)
+    src: str | None = CharField(63, unique=True)
     trgt: str | None = CharField(63)
     used_at: datetime | None = DatetimeSecField(null=True)
 
@@ -869,8 +870,8 @@ class Dep(Model, TsTrait):
 
     def repr(self):
         return (
-            f'{self.coin.ticker}:{self.apr * 100:.3g}% '
-            f'{f"{self.duration}d" if self.duration and self.duration > 0 else "flex"}'
+            f"{self.coin.ticker}:{self.apr * 100:.3g}% "
+            f"{f'{self.duration}d' if self.duration and self.duration > 0 else 'flex'}"
         )
 
     class Meta:
